@@ -33,8 +33,8 @@ Q_OBJECT
 public:
 	SambaContainer(QWidget *parent=0, const QVariantList &list = QVariantList());
 	virtual ~SambaContainer();
-	virtual void load();
-	virtual void save();
+	void load() Q_DECL_OVERRIDE;
+	void save() Q_DECL_OVERRIDE;
 
 private:
 	KConfig config;
@@ -48,7 +48,6 @@ private:
 K_PLUGIN_FACTORY(SambaFactory,
 		registerPlugin<SambaContainer>();
 )
-K_EXPORT_PLUGIN(SambaFactory("kcmsamba"))
 
 SambaContainer::SambaContainer(QWidget *parent, const QVariantList&) :
 	KCModule(parent), config(QStringLiteral("kcmsambarc")), tabs(this), status(&tabs, &config), imports(&tabs, &config), logView(&tabs, &config), statisticsView(&tabs, &config) {
